summaryrefslogtreecommitdiff
path: root/server_config.go
diff options
context:
space:
mode:
authorWolfy-J <[email protected]>2018-06-06 16:34:31 +0300
committerWolfy-J <[email protected]>2018-06-06 16:34:31 +0300
commit78fee1f14e39bbb36204737d2fc6be985614911d (patch)
tree2e6c51d3ef6b7bad64eeff9ea4693a0967dc83b7 /server_config.go
parent8a22b1bdda462075bfc56f17110eb3c0dc1f3f79 (diff)
more tests
Diffstat (limited to 'server_config.go')
-rw-r--r--server_config.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/server_config.go b/server_config.go
index 1491e833..7e8aa80e 100644
--- a/server_config.go
+++ b/server_config.go
@@ -35,9 +35,9 @@ type ServerConfig struct {
// This config section must not change on re-configuration.
Relay string
// FactoryTimeout defines for how long socket factory will be waiting for worker connection. This config section
// must not change on re-configuration.
- FactoryTimeout time.Duration
+ RelayTimeout time.Duration
// Pool defines worker pool configuration, number of workers, timeouts and etc. This config section might change
// while server is running.
@@ -52,7 +52,7 @@ func (cfg *ServerConfig) Differs(new *ServerConfig) bool {
}
// factory configuration has changed
- return cfg.Relay != new.Relay || cfg.FactoryTimeout != new.FactoryTimeout
+ return cfg.Relay != new.Relay || cfg.RelayTimeout != new.RelayTimeout
}
// makeCommands returns new command provider based on configured options.
@@ -125,5 +125,5 @@ func (cfg *ServerConfig) makeFactory() (Factory, error) {
return nil, nil
}
- return NewSocketFactory(ln, time.Second*cfg.FactoryTimeout), nil
+ return NewSocketFactory(ln, cfg.RelayTimeout), nil
}
@@ -35,9 +35,9 @@ type ServerConfig struct {
// This config section must not change on re-configuration.
Relay string
- // FactoryTimeout defines for how long socket factory will be waiting for worker connection. This config section
+ // RelayTimeout defines for how long socket factory will be waiting for worker connection. This config section
// must not change on re-configuration.